Usage
=====
.. autofunction:: pystow.join
.. autofunction:: pystow.module
.. autofunction:: pystow.ensure
.. autofunction:: pystow.ensure_untar

Ensure with Parsing
-------------------
.. autofunction:: pystow.ensure_csv
.. autofunction:: pystow.ensure_excel
.. autofunction:: pystow.ensure_rdf

Inside a ZIP File
~~~~~~~~~~~~~~~~~
.. autofunction:: pystow.ensure_zip_df

Inside a TAR File
~~~~~~~~~~~~~~~~~
.. autofunction:: pystow.ensure_tar_df
.. autofunction:: pystow.ensure_tar_xml
